@@ -220,11 +220,8 @@ abstract class BDGraphicsBase extends DVBGraphics implements ConstrainableGraphi
     }
 
     public FontMetrics getFontMetrics() {
-        if (font != null && fontMetrics == null) {
-            fontMetrics = BDFontMetrics.getFontMetrics(font);
-        }
         if (fontMetrics == null) {
-            logger.error("getFontMetrics() failed");
+            fontMetrics = BDFontMetrics.getFontMetrics(getFont());
         }
         return fontMetrics;
     }
@@ -283,14 +280,14 @@ abstract class BDGraphicsBase extends DVBGraphics implements ConstrainableGraphi
     }
 
     public void constrain(int x, int y, int w, int h) {
-        Rectangle rect;
-        if (constrainedRect != null)
-            rect = constrainedRect;
-        else
-            rect = new Rectangle(0, 0, width, height);
-        constrainedRect = rect.intersection(new Rectangle(rect.x + x, rect.y + y, w, h));
-        originX = constrainedRect.x;
-        originY = constrainedRect.y;
+        originX += x;
+        originY += y;
+        Rectangle r = new Rectangle(originX, originY, w, h);
+        if (constrainedRect != null) {
+            constrainedRect = constrainedRect.intersection(r);
+        } else {
+            constrainedRect = r;
+        }
         setupClip();
     }
 
@@ -724,7 +721,7 @@ abstract class BDGraphicsBase extends DVBGraphics implements ConstrainableGraphi
             for (int j = 0; j < nPoints; j++) {
                 if (polyEdges[j].intersects(i)) {
                     int x = polyEdges[j].intersectionX(i);
-                    xList.add(new Integer(x));
+                    xList.add(Integer.valueOf(x));
                 }
             }
 
